OpenCV iOS {#tutorial_table_of_content_ios}
==========

-   @subpage tutorial_hello

    *Languages:* Objective-C++

    *Compatibility:* \> OpenCV 2.4.3

    *Author:* Charu Hans

    You will learn how to link OpenCV with iOS and write a basic application.

-   @subpage tutorial_image_manipulation

    *Languages:* Objective-C++

    *Compatibility:* \> OpenCV 2.4.3

    *Author:* Charu Hans

    You will learn how to do simple image manipulation using OpenCV in iOS.

-   @subpage tutorial_video_processing

    *Languages:* Objective-C++

    *Compatibility:* \> OpenCV 2.4.3

    *Author:* Eduard Feicho

    You will learn how to capture and process video from camera using OpenCV in iOS.
